@@ -19,7 +19,7 @@ use constant SPECIFICATION_URL => 'http://json-schema.org/draft-04/schema#';
 
 use constant DEBUG => $ENV{JSON_VALIDATOR_DEBUG} || 0;
 
-our $VERSION = '1.03';
+our $VERSION = '1.04';
 our @EXPORT_OK = 'validate_json';
 
 my $BUNDLED_CACHE_DIR = path(path(__FILE__)->dirname, qw(Validator cache));
@@ -615,7 +615,7 @@ sub _validate_type_object {
   while (my ($k, $r) = each %{$schema->{properties}}) {
     push @{$rules{$k}}, $r;
   }
-  while (my ($p, $r) = each %{$schema->{patternProperties}}) {
+  while (my ($p, $r) = each %{$schema->{patternProperties} || {}}) {
     push @{$rules{$_}}, $r for grep { $_ =~ /$p/ } keys %$data;
   }
 
@@ -879,7 +879,7 @@ JSON::Validator - Validate data against a JSON schema
 
 =head1 VERSION
 
-1.03
+1.04
 
 =head1 SYNOPSIS
 
